==> opennms-integration-otrs-31-18.0.0-20151111.022742-45-sources.jar: org/otrs/ticketconnector/OTRSPendingTime.java <==

package org.otrs.ticketconnector;

import java.io.Serializable;
import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.opennms.netmgt.ticketer.otrs31.BigIntegerAdapter;


/**
 * <p>Java class for OTRS_PendingTime complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OTRS_PendingTime"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="Year" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *         &lt;element name="Month" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *         &lt;element name="Day" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *         &lt;element name="Hour" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *         &lt;element name="Minute" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OTRS_PendingTime", propOrder = {
    "year",
    "month",
    "day",
    "hour",
    "minute"
})
public class OTRSPendingTime
    implements Serializable
{

    @XmlElement(name = "Year", required = true, type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger year;
    @XmlElement(name = "Month", required = true, type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger month;
    @XmlElement(name = "Day", required = true, type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger day;
    @XmlElement(name = "Hour", required = true, type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger hour;
    @XmlElement(name = "Minute", required = true, type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger minute;

    /**
     * Gets the value of the year property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getYear() {
        return year;
    }

    /**
     * Sets the value of the year property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setYear(BigInteger value) {
        this.year = value;
    }

    /**
     * Gets the value of the month property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getMonth() {
        return month;
    }

    /**
     * Sets the value of the month property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMonth(BigInteger value) {
        this.month = value;
    }

    /**
     * Gets the value of the day property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getDay() {
        return day;
    }

    /**
     * Sets the value of the day property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDay(BigInteger value) {
        this.day = value;
    }

    /**
     * Gets the value of the hour property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getHour() {
        return hour;
    }

    /**
     * Sets the value of the hour property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHour(BigInteger value) {
        this.hour = value;
    }

    /**
     * Gets the value of the minute property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getMinute() {
        return minute;
    }

    /**
     * Sets the value of the minute property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMinute(BigInteger value) {
        this.minute = value;
    }

}

==> opennms-integration-otrs-31-19.0.0-20181016.012045-316-sources.jar: org/otrs/ticketconnector/OTRSPendingTime.java <==

package org.otrs.ticketconnector;

import java.io.Serializable;
import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.opennms.netmgt.ticketer.otrs31.BigIntegerAdapter;


/**
 * <p>Java class for OTRS_PendingTime complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OTRS_PendingTime"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;sequence&gt;
 *           &lt;element name="Year" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *           &lt;element name="Month" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *           &lt;element name="Day" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *           &lt;element name="Hour" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *           &lt;element name="Minute" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *         &lt;/sequence&gt;
 *         &lt;element name="Diff" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OTRS_PendingTime", propOrder = {
    "year",
    "month",
    "day",
    "hour",
    "minute",
    "diff"
})
public class OTRSPendingTime
    implements Serializable
{

    @XmlElement(name = "Year", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger year;
    @XmlElement(name = "Month", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger month;
    @XmlElement(name = "Day", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger day;
    @XmlElement(name = "Hour", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger hour;
    @XmlElement(name = "Minute", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger minute;
    @XmlElement(name = "Diff", type = String.class)
    @XmlJavaTypeAdapter(BigIntegerAdapter.class)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger diff;

    /**
     * Gets the value of the year property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getYear() {
        return year;
    }

    /**
     * Sets the value of the year property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setYear(BigInteger value) {
        this.year = value;
    }

    /**
     * Gets the value of the month property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getMonth() {
        return month;
    }

    /**
     * Sets the value of the month property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMonth(BigInteger value) {
        this.month = value;
    }

    /**
     * Gets the value of the day property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getDay() {
        return day;
    }

    /**
     * Sets the value of the day property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDay(BigInteger value) {
        this.day = value;
    }

    /**
     * Gets the value of the hour property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getHour() {
        return hour;
    }

    /**
     * Sets the value of the hour property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHour(BigInteger value) {
        this.hour = value;
    }

    /**
     * Gets the value of the minute property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getMinute() {
        return minute;
    }

    /**
     * Sets the value of the minute property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMinute(BigInteger value) {
        this.minute = value;
    }

    /**
     * Gets the value of the diff property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public BigInteger getDiff() {
        return diff;
    }

    /**
     * Sets the value of the diff property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDiff(BigInteger value) {
        this.diff = value;
    }

}
